﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Infragistics.Windows.Editors;
using System.Collections.ObjectModel;
using System.Windows;

namespace Infragistics.Samples
{
	/// <summary>
	/// Static class with members for dealing with xamMonthCalendar
	/// </summary>
	public static class MonthCalendarHelpers
	{
		#region DisabledDates

		// note I was going to make the property type be IList<CalendarDateRange> but then when using an 
		// x:Array or any collection class (like DateRangeCollection) results in an error being listed 
		// by vs in the error list even though it compiles and works fine. so to avoid issues 
		/// <summary>
		/// DisabledDates attached DependencyProperty
		/// </summary>
		public static readonly DependencyProperty DisabledDatesProperty =
			DependencyProperty.RegisterAttached("DisabledDates", typeof(DateRangeCollection), typeof(MonthCalendarHelpers),
				new FrameworkPropertyMetadata(null, new PropertyChangedCallback(OnDisabledDatesChanged)));

		/// <summary>
		/// Gets the DisabledDates that will be used to populate a xamMonthCalendar's DisabledDates
		/// </summary>
		public static DateRangeCollection GetDisabledDates(DependencyObject d)
		{
			return (DateRangeCollection)d.GetValue(DisabledDatesProperty);
		}

		/// <summary>
		/// Sets the DisabledDates that will be used to populate a xamMonthCalendar's DisabledDates
		/// </summary>
		public static void SetDisabledDates(DependencyObject d, DateRangeCollection value)
		{
			d.SetValue(DisabledDatesProperty, value);
		}

		private static void OnDisabledDatesChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
		{
			XamMonthCalendar mc = d as XamMonthCalendar;

			// if this property is being set on a xamMonthCalendar then update the disabled dates
			if (mc != null)
			{
				// if you planned on supporting a modifiable collection then you would have to 
				// do extra work here to hook the notifycollection change, etc.
				IList<CalendarDateRange> newList = e.NewValue as IList<CalendarDateRange> ?? new CalendarDateRange[0];
				mc.DisabledDates.ReInitialize(newList);
			}
		}
		#endregion // DisabledDates
	}

	/// <summary>
	/// A collection of <see cref="CalendarDateRange"/>
	/// </summary>
	public class DateRangeCollection : List<CalendarDateRange>
	{
	}
}
